conda
=====

Install a Conda_ recipe in the package to generate Conda_ packages.

Modifications
-------------

.. raw:: html
    :file: modifications.html



.. _Conda: http://conda.pydata.org/docs/intro.html
